@@ -2,6 +2,7 @@
 # Copyright (c) 2020 Kian Cross
 #
 
+from typing import cast
 from pixy.escape_sequence import EscapeSequence
 
 
@@ -10,11 +11,11 @@ class Font(EscapeSequence):
     __FONT_START_CODE = 11
     __FONT_END_CODE = 19
 
-    def __new__(self, font_number: int):
+    def __new__(cls, font_number: int) -> "Font":
 
-        number_of_fonts = self.__FONT_END_CODE - self.__FONT_START_CODE
+        number_of_fonts = cls.__FONT_END_CODE - cls.__FONT_START_CODE
 
         if font_number < 0 or font_number > number_of_fonts:
             raise ValueError("font must be in-between 0 and %d" % number_of_fonts)
 
-        return super().__new__(self, self.__FONT_START_CODE + font_number)
+        return cast(Font, super().__new__(cls, cls.__FONT_START_CODE + font_number))
